@@ -1,11 +1,11 @@
 """A FastAPI Framework for things like Database, Redis, Logging, JWT Authentication and Rate Limits"""
 
-__version__ = "1.1.1"
+__version__ = "1.3.0"
 
 from .modules import check_dependencies, disabled_modules
 
 check_dependencies()  # noqa: FLK-E402
-from .database import db
+from .database import database_dependency
 from .jwt_auth import (
     create_jwt_token,
     create_access_token,
